Class: AutosdeOpenapiClient::StorageSystem
- Inherits:
-
Object
- Object
- AutosdeOpenapiClient::StorageSystem
- Defined in:
- lib/autosde_openapi_client/models/storage_system.rb
Overview
Use to define storage system properties.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_add_pools ⇒ Object
auto_add_pools.
-
#component_state ⇒ Object
component_state.
-
#management_ip ⇒ Object
management_ip.
-
#name ⇒ Object
name.
-
#storage_array ⇒ Object
storage_array.
-
#storage_family ⇒ Object
storage_family.
-
#system_type ⇒ Object
Returns the value of attribute system_type.
-
#uuid ⇒ Object
uuid.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageSystem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageSystem
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::StorageSystem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::StorageSystem`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_add_pools') self.auto_add_pools = attributes[:'auto_add_pools'] else self.auto_add_pools = false end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'management_ip') self.management_ip = attributes[:'management_ip'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'storage_array') self.storage_array = attributes[:'storage_array'] end if attributes.key?(:'storage_family') self.storage_family = attributes[:'storage_family'] end if attributes.key?(:'system_type') self.system_type = attributes[:'system_type'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end end |
Instance Attribute Details
#auto_add_pools ⇒ Object
auto_add_pools
20 21 22 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 20 def auto_add_pools @auto_add_pools end |
#component_state ⇒ Object
component_state
23 24 25 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 23 def component_state @component_state end |
#management_ip ⇒ Object
management_ip
26 27 28 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 26 def management_ip @management_ip end |
#name ⇒ Object
name
29 30 31 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 29 def name @name end |
#storage_array ⇒ Object
storage_array
32 33 34 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 32 def storage_array @storage_array end |
#storage_family ⇒ Object
storage_family
35 36 37 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 35 def storage_family @storage_family end |
#system_type ⇒ Object
Returns the value of attribute system_type.
37 38 39 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 37 def system_type @system_type end |
#uuid ⇒ Object
uuid
40 41 42 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 40 def uuid @uuid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 79 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 65 def self.attribute_map { :'auto_add_pools' => :'auto_add_pools', :'component_state' => :'component_state', :'management_ip' => :'management_ip', :'name' => :'name', :'storage_array' => :'storage_array', :'storage_family' => :'storage_family', :'system_type' => :'system_type', :'uuid' => :'uuid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 240 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 84 def self.openapi_types { :'auto_add_pools' => :'Boolean', :'component_state' => :'String', :'management_ip' => :'String', :'name' => :'String', :'storage_array' => :'String', :'storage_family' => :'String', :'system_type' => :'SystemType', :'uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && auto_add_pools == o.auto_add_pools && component_state == o.component_state && management_ip == o.management_ip && name == o.name && storage_array == o.storage_array && storage_family == o.storage_family && system_type == o.system_type && uuid == o.uuid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 270 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AutosdeOpenapiClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 341 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 247 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 233 def hash [auto_add_pools, component_state, management_ip, name, storage_array, storage_family, system_type, uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 155 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end if !@name.nil? && @name.to_s.length > 15 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 15.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
317 318 319 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 317 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
311 312 313 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 311 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 |
# File 'lib/autosde_openapi_client/models/storage_system.rb', line 170 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 return false if !@name.nil? && @name.to_s.length > 15 storage_family_validator = EnumAttributeValidator.new('String', ["", "ontap_7mode", "ontap_cluster"]) return false unless storage_family_validator.valid?(@storage_family) true end |