Class: AutosdeOpenapiClient::StorageSystemCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/autosde_openapi_client/models/storage_system_create.rb

Overview

TODO add description

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageSystemCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 158

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::StorageSystemCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::StorageSystemCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_refresh')
    self.auto_refresh = attributes[:'auto_refresh']
  else
    self.auto_refresh = true
  end

  if attributes.key?(:'chap_name')
    self.chap_name = attributes[:'chap_name']
  end

  if attributes.key?(:'chap_secret')
    self.chap_secret = attributes[:'chap_secret']
  end

  if attributes.key?(:'component_state')
    self.component_state = attributes[:'component_state']
  end

  if attributes.key?(:'enabled_capability_values')
    self.enabled_capability_values = attributes[:'enabled_capability_values']
  end

  if attributes.key?(:'initial_refresh')
    self.initial_refresh = attributes[:'initial_refresh']
  else
    self.initial_refresh = true
  end

  if attributes.key?(:'iqn')
    self.iqn = attributes[:'iqn']
  end

  if attributes.key?(:'management_ip')
    self.management_ip = attributes[:'management_ip']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'port_type')
    self.port_type = attributes[:'port_type']
  end

  if attributes.key?(:'secondary_ip')
    self.secondary_ip = attributes[:'secondary_ip']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'storage_array')
    self.storage_array = attributes[:'storage_array']
  end

  if attributes.key?(:'storage_driver')
    self.storage_driver = attributes[:'storage_driver']
  end

  if attributes.key?(:'storage_family')
    self.storage_family = attributes[:'storage_family']
  end

  if attributes.key?(:'system_type')
    self.system_type = attributes[:'system_type']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'wwpn')
    self.wwpn = attributes[:'wwpn']
  end
end

Instance Attribute Details

#auto_refreshObject

auto_refresh



20
21
22
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 20

def auto_refresh
  @auto_refresh
end

#chap_nameObject

chap_name



23
24
25
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 23

def chap_name
  @chap_name
end

#chap_secretObject

chap_secret



26
27
28
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 26

def chap_secret
  @chap_secret
end

#component_stateObject

component_state



29
30
31
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 29

def component_state
  @component_state
end

#enabled_capability_valuesObject

Returns the value of attribute enabled_capability_values.



31
32
33
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 31

def enabled_capability_values
  @enabled_capability_values
end

#initial_refreshObject

initial_refresh



34
35
36
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 34

def initial_refresh
  @initial_refresh
end

#iqnObject

Returns the value of attribute iqn.



36
37
38
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 36

def iqn
  @iqn
end

#management_ipObject

management_ip



39
40
41
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 39

def management_ip
  @management_ip
end

#nameObject

name



42
43
44
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 42

def name
  @name
end

#passwordObject

password



45
46
47
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 45

def password
  @password
end

#port_typeObject

port_type



48
49
50
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 48

def port_type
  @port_type
end

#secondary_ipObject

secondary_ip



51
52
53
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 51

def secondary_ip
  @secondary_ip
end

#statusObject

status



54
55
56
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 54

def status
  @status
end

#storage_arrayObject

storage_array



57
58
59
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 57

def storage_array
  @storage_array
end

#storage_driverObject

storage_driver



60
61
62
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 60

def storage_driver
  @storage_driver
end

#storage_familyObject

storage_family



63
64
65
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 63

def storage_family
  @storage_family
end

#system_typeObject

Returns the value of attribute system_type.



65
66
67
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 65

def system_type
  @system_type
end

#userObject

user



68
69
70
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 68

def user
  @user
end

#wwpnObject

wwpn



71
72
73
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 71

def wwpn
  @wwpn
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



121
122
123
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 121

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 96

def self.attribute_map
  {
    :'auto_refresh' => :'auto_refresh',
    :'chap_name' => :'chap_name',
    :'chap_secret' => :'chap_secret',
    :'component_state' => :'component_state',
    :'enabled_capability_values' => :'enabled_capability_values',
    :'initial_refresh' => :'initial_refresh',
    :'iqn' => :'iqn',
    :'management_ip' => :'management_ip',
    :'name' => :'name',
    :'password' => :'password',
    :'port_type' => :'port_type',
    :'secondary_ip' => :'secondary_ip',
    :'status' => :'status',
    :'storage_array' => :'storage_array',
    :'storage_driver' => :'storage_driver',
    :'storage_family' => :'storage_family',
    :'system_type' => :'system_type',
    :'user' => :'user',
    :'wwpn' => :'wwpn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



347
348
349
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 347

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



151
152
153
154
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 151

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 126

def self.openapi_types
  {
    :'auto_refresh' => :'Boolean',
    :'chap_name' => :'String',
    :'chap_secret' => :'String',
    :'component_state' => :'String',
    :'enabled_capability_values' => :'ServiceAbstractCapabilityValue',
    :'initial_refresh' => :'Boolean',
    :'iqn' => :'String',
    :'management_ip' => :'String',
    :'name' => :'String',
    :'password' => :'String',
    :'port_type' => :'String',
    :'secondary_ip' => :'String',
    :'status' => :'String',
    :'storage_array' => :'String',
    :'storage_driver' => :'String',
    :'storage_family' => :'String',
    :'system_type' => :'SystemType',
    :'user' => :'String',
    :'wwpn' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 308

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_refresh == o.auto_refresh &&
      chap_name == o.chap_name &&
      chap_secret == o.chap_secret &&
      component_state == o.component_state &&
      enabled_capability_values == o.enabled_capability_values &&
      initial_refresh == o.initial_refresh &&
      iqn == o.iqn &&
      management_ip == o.management_ip &&
      name == o.name &&
      password == o.password &&
      port_type == o.port_type &&
      secondary_ip == o.secondary_ip &&
      status == o.status &&
      storage_array == o.storage_array &&
      storage_driver == o.storage_driver &&
      storage_family == o.storage_family &&
      system_type == o.system_type &&
      user == o.user &&
      wwpn == o.wwpn
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 377

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AutosdeOpenapiClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 448

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 354

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


334
335
336
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 334

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



340
341
342
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 340

def hash
  [auto_refresh, chap_name, chap_secret, component_state, enabled_capability_values, initial_refresh, iqn, management_ip, name, password, port_type, secondary_ip, status, storage_array, storage_driver, storage_family, system_type, user, wwpn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



254
255
256
257
258
259
260
261
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 254

def list_invalid_properties
  invalid_properties = Array.new
  if !@component_state.nil? && @component_state.to_s.length > 32
    invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 424

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 430

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



418
419
420
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 418

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



265
266
267
268
269
270
271
272
273
274
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 265

def valid?
  component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"])
  return false unless component_state_validator.valid?(@component_state)
  return false if !@component_state.nil? && @component_state.to_s.length > 32
  port_type_validator = EnumAttributeValidator.new('String', ["ISCSI", "FC", "NVMeFC"])
  return false unless port_type_validator.valid?(@port_type)
  storage_family_validator = EnumAttributeValidator.new('String', ["", "ontap_7mode", "ontap_cluster"])
  return false unless storage_family_validator.valid?(@storage_family)
  true
end