Class: AutosdeOpenapiClient::StorageSystemResponse
- Inherits:
-
Object
- Object
- AutosdeOpenapiClient::StorageSystemResponse
- Defined in:
- lib/autosde_openapi_client/models/storage_system_response.rb
Overview
TODO add description
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_refresh ⇒ Object
auto_refresh.
-
#component_state ⇒ Object
component_state.
-
#enabled_capability_values ⇒ Object
enabled_capability_values.
-
#management_ip ⇒ Object
management_ip.
-
#name ⇒ Object
name.
-
#status ⇒ Object
status.
-
#storage_array ⇒ Object
storage_array.
-
#storage_family ⇒ Object
storage_family.
-
#system_type ⇒ Object
Returns the value of attribute system_type.
-
#uuid ⇒ Object
uuid.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageSystemResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageSystemResponse
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::StorageSystemResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::StorageSystemResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_refresh') self.auto_refresh = attributes[:'auto_refresh'] else self.auto_refresh = true end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'enabled_capability_values') if (value = attributes[:'enabled_capability_values']).is_a?(Array) self.enabled_capability_values = value end end if attributes.key?(:'management_ip') self.management_ip = attributes[:'management_ip'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'storage_array') self.storage_array = attributes[:'storage_array'] end if attributes.key?(:'storage_family') self.storage_family = attributes[:'storage_family'] end if attributes.key?(:'system_type') self.system_type = attributes[:'system_type'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end end |
Instance Attribute Details
#auto_refresh ⇒ Object
auto_refresh
20 21 22 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 20 def auto_refresh @auto_refresh end |
#component_state ⇒ Object
component_state
23 24 25 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 23 def component_state @component_state end |
#enabled_capability_values ⇒ Object
enabled_capability_values
26 27 28 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 26 def enabled_capability_values @enabled_capability_values end |
#management_ip ⇒ Object
management_ip
29 30 31 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 29 def management_ip @management_ip end |
#name ⇒ Object
name
32 33 34 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 32 def name @name end |
#status ⇒ Object
status
35 36 37 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 35 def status @status end |
#storage_array ⇒ Object
storage_array
38 39 40 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 38 def storage_array @storage_array end |
#storage_family ⇒ Object
storage_family
41 42 43 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 41 def storage_family @storage_family end |
#system_type ⇒ Object
Returns the value of attribute system_type.
43 44 45 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 43 def system_type @system_type end |
#uuid ⇒ Object
uuid
46 47 48 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 46 def uuid @uuid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 87 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 71 def self.attribute_map { :'auto_refresh' => :'auto_refresh', :'component_state' => :'component_state', :'enabled_capability_values' => :'enabled_capability_values', :'management_ip' => :'management_ip', :'name' => :'name', :'status' => :'status', :'storage_array' => :'storage_array', :'storage_family' => :'storage_family', :'system_type' => :'system_type', :'uuid' => :'uuid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 247 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 92 def self.openapi_types { :'auto_refresh' => :'Boolean', :'component_state' => :'String', :'enabled_capability_values' => :'Array<ServiceAbstractCapabilityValue>', :'management_ip' => :'String', :'name' => :'String', :'status' => :'String', :'storage_array' => :'String', :'storage_family' => :'String', :'system_type' => :'SystemType', :'uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 217 def ==(o) return true if self.equal?(o) self.class == o.class && auto_refresh == o.auto_refresh && component_state == o.component_state && enabled_capability_values == o.enabled_capability_values && management_ip == o.management_ip && name == o.name && status == o.status && storage_array == o.storage_array && storage_family == o.storage_family && system_type == o.system_type && uuid == o.uuid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 277 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AutosdeOpenapiClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 348 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 254 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 240 def hash [auto_refresh, component_state, enabled_capability_values, management_ip, name, status, storage_array, storage_family, system_type, uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 175 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
324 325 326 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 324 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 330 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
318 319 320 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 318 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 |
# File 'lib/autosde_openapi_client/models/storage_system_response.rb', line 186 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 storage_family_validator = EnumAttributeValidator.new('String', ["", "ontap_7mode", "ontap_cluster"]) return false unless storage_family_validator.valid?(@storage_family) true end |