Class: AutosdeOpenapiClient::Volume
- Inherits:
-
Object
- Object
- AutosdeOpenapiClient::Volume
- Defined in:
- lib/autosde_openapi_client/models/volume.rb
Overview
Define volume properties on a specific storage resource.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#compliant ⇒ Object
compliant.
-
#component_state ⇒ Object
component_state.
-
#fc_map_count ⇒ Object
fc_map_count.
-
#historical_service ⇒ Object
Returns the value of attribute historical_service.
-
#name ⇒ Object
name.
-
#service ⇒ Object
Returns the value of attribute service.
-
#size ⇒ Object
size.
-
#status ⇒ Object
status.
-
#storage_resource ⇒ Object
Returns the value of attribute storage_resource.
-
#unmapped_since ⇒ Object
unmapped_since.
-
#uuid ⇒ Object
uuid.
-
#volume_name ⇒ Object
volume_name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Volume
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Volume
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::Volume` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::Volume`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'compliant') self.compliant = attributes[:'compliant'] else self.compliant = false end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'fc_map_count') self.fc_map_count = attributes[:'fc_map_count'] else self.fc_map_count = 0 end if attributes.key?(:'historical_service') self.historical_service = attributes[:'historical_service'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'storage_resource') self.storage_resource = attributes[:'storage_resource'] end if attributes.key?(:'unmapped_since') self.unmapped_since = attributes[:'unmapped_since'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'volume_name') self.volume_name = attributes[:'volume_name'] end end |
Instance Attribute Details
#compliant ⇒ Object
compliant
20 21 22 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 20 def compliant @compliant end |
#component_state ⇒ Object
component_state
23 24 25 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 23 def component_state @component_state end |
#fc_map_count ⇒ Object
fc_map_count
26 27 28 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 26 def fc_map_count @fc_map_count end |
#historical_service ⇒ Object
Returns the value of attribute historical_service.
28 29 30 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 28 def historical_service @historical_service end |
#name ⇒ Object
name
31 32 33 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 31 def name @name end |
#service ⇒ Object
Returns the value of attribute service.
33 34 35 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 33 def service @service end |
#size ⇒ Object
size
36 37 38 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 36 def size @size end |
#status ⇒ Object
status
39 40 41 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 39 def status @status end |
#storage_resource ⇒ Object
Returns the value of attribute storage_resource.
41 42 43 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 41 def storage_resource @storage_resource end |
#unmapped_since ⇒ Object
unmapped_since
44 45 46 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 44 def unmapped_since @unmapped_since end |
#uuid ⇒ Object
uuid
47 48 49 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 47 def uuid @uuid end |
#volume_name ⇒ Object
volume_name
50 51 52 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 50 def volume_name @volume_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 93 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 75 def self.attribute_map { :'compliant' => :'compliant', :'component_state' => :'component_state', :'fc_map_count' => :'fc_map_count', :'historical_service' => :'historical_service', :'name' => :'name', :'service' => :'service', :'size' => :'size', :'status' => :'status', :'storage_resource' => :'storage_resource', :'unmapped_since' => :'unmapped_since', :'uuid' => :'uuid', :'volume_name' => :'volume_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 253 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 98 def self.openapi_types { :'compliant' => :'Boolean', :'component_state' => :'String', :'fc_map_count' => :'Integer', :'historical_service' => :'Service', :'name' => :'String', :'service' => :'Service', :'size' => :'Integer', :'status' => :'String', :'storage_resource' => :'StorageResource', :'unmapped_since' => :'Time', :'uuid' => :'String', :'volume_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && compliant == o.compliant && component_state == o.component_state && fc_map_count == o.fc_map_count && historical_service == o.historical_service && name == o.name && service == o.service && size == o.size && status == o.status && storage_resource == o.storage_resource && unmapped_since == o.unmapped_since && uuid == o.uuid && volume_name == o.volume_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 283 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AutosdeOpenapiClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 354 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 260 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 246 def hash [compliant, component_state, fc_map_count, historical_service, name, service, size, status, storage_resource, unmapped_since, uuid, volume_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 191 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
330 331 332 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 330 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
324 325 326 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 324 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 |
# File 'lib/autosde_openapi_client/models/volume.rb', line 202 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION", "CLONING"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 true end |