Class: AutosdeOpenapiClient::VolumeCreate
- Inherits:
-
Object
- Object
- AutosdeOpenapiClient::VolumeCreate
- Defined in:
- lib/autosde_openapi_client/models/volume_create.rb
Overview
TODO add description
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#compliant ⇒ Object
compliant.
-
#component_state ⇒ Object
component_state.
-
#count ⇒ Object
count.
-
#fc_map_count ⇒ Object
fc_map_count.
-
#name ⇒ Object
name.
-
#resources ⇒ Object
resources.
-
#service ⇒ Object
Returns the value of attribute service.
-
#service_name ⇒ Object
service_name.
-
#size ⇒ Object
size.
-
#status ⇒ Object
status.
-
#unmapped_since ⇒ Object
unmapped_since.
-
#uuid ⇒ Object
uuid.
-
#volume_name ⇒ Object
volume_name.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumeCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VolumeCreate
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::VolumeCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::VolumeCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'compliant') self.compliant = attributes[:'compliant'] else self.compliant = false end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'count') self.count = attributes[:'count'] else self.count = 1 end if attributes.key?(:'fc_map_count') self.fc_map_count = attributes[:'fc_map_count'] else self.fc_map_count = 0 end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'resources') if (value = attributes[:'resources']).is_a?(Array) self.resources = value end end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'service_name') self.service_name = attributes[:'service_name'] else self.service_name = 'null' end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'unmapped_since') self.unmapped_since = attributes[:'unmapped_since'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'volume_name') self.volume_name = attributes[:'volume_name'] end end |
Instance Attribute Details
#compliant ⇒ Object
compliant
20 21 22 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 20 def compliant @compliant end |
#component_state ⇒ Object
component_state
23 24 25 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 23 def component_state @component_state end |
#count ⇒ Object
count
26 27 28 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 26 def count @count end |
#fc_map_count ⇒ Object
fc_map_count
29 30 31 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 29 def fc_map_count @fc_map_count end |
#name ⇒ Object
name
32 33 34 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 32 def name @name end |
#resources ⇒ Object
resources
35 36 37 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 35 def resources @resources end |
#service ⇒ Object
Returns the value of attribute service.
37 38 39 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 37 def service @service end |
#service_name ⇒ Object
service_name
40 41 42 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 40 def service_name @service_name end |
#size ⇒ Object
size
43 44 45 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 43 def size @size end |
#status ⇒ Object
status
46 47 48 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 46 def status @status end |
#unmapped_since ⇒ Object
unmapped_since
49 50 51 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 49 def unmapped_since @unmapped_since end |
#uuid ⇒ Object
uuid
52 53 54 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 52 def uuid @uuid end |
#volume_name ⇒ Object
volume_name
55 56 57 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 55 def volume_name @volume_name end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 99 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 80 def self.attribute_map { :'compliant' => :'compliant', :'component_state' => :'component_state', :'count' => :'count', :'fc_map_count' => :'fc_map_count', :'name' => :'name', :'resources' => :'resources', :'service' => :'service', :'service_name' => :'service_name', :'size' => :'size', :'status' => :'status', :'unmapped_since' => :'unmapped_since', :'uuid' => :'uuid', :'volume_name' => :'volume_name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 271 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 104 def self.openapi_types { :'compliant' => :'Boolean', :'component_state' => :'String', :'count' => :'Integer', :'fc_map_count' => :'Integer', :'name' => :'String', :'resources' => :'Array<String>', :'service' => :'Service', :'service_name' => :'String', :'size' => :'Integer', :'status' => :'String', :'unmapped_since' => :'Time', :'uuid' => :'String', :'volume_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && compliant == o.compliant && component_state == o.component_state && count == o.count && fc_map_count == o.fc_map_count && name == o.name && resources == o.resources && service == o.service && service_name == o.service_name && size == o.size && status == o.status && unmapped_since == o.unmapped_since && uuid == o.uuid && volume_name == o.volume_name end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 301 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = AutosdeOpenapiClient.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 372 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 278 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 264 def hash [compliant, component_state, count, fc_map_count, name, resources, service, service_name, size, status, unmapped_since, uuid, volume_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
208 209 210 211 212 213 214 215 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 208 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
348 349 350 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 348 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 354 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
342 343 344 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 342 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 |
# File 'lib/autosde_openapi_client/models/volume_create.rb', line 219 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION", "CLONING"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 true end |