Class: OpenapiClient::AutoSDEProject

Inherits:
Object
  • Object
show all
Defined in:
lib/autosde_openapi_client/models/auto_sde_project.rb

Overview

Use this for AutoSDE project information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AutoSDEProject

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::AutoSDEProject` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::AutoSDEProject`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cores')
    self.cores = attributes[:'cores']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'fixed_ips')
    self.fixed_ips = attributes[:'fixed_ips']
  end

  if attributes.key?(:'floating_ips')
    self.floating_ips = attributes[:'floating_ips']
  end

  if attributes.key?(:'groups')
    self.groups = attributes[:'groups']
  end

  if attributes.key?(:'injected_file_content_bytes')
    self.injected_file_content_bytes = attributes[:'injected_file_content_bytes']
  end

  if attributes.key?(:'injected_file_path_bytes')
    self.injected_file_path_bytes = attributes[:'injected_file_path_bytes']
  end

  if attributes.key?(:'instances')
    self.instances = attributes[:'instances']
  end

  if attributes.key?(:'key_pairs')
    self.key_pairs = attributes[:'key_pairs']
  end

  if attributes.key?(:'max_total_backup_gigabytes')
    self.max_total_backup_gigabytes = attributes[:'max_total_backup_gigabytes']
  end

  if attributes.key?(:'max_total_backups')
    self.max_total_backups = attributes[:'max_total_backups']
  end

  if attributes.key?(:'max_total_snapshots')
    self.max_total_snapshots = attributes[:'max_total_snapshots']
  end

  if attributes.key?(:'max_total_volume_gigabytes')
    self.max_total_volume_gigabytes = attributes[:'max_total_volume_gigabytes']
  end

  if attributes.key?(:'max_total_volumes')
    self.max_total_volumes = attributes[:'max_total_volumes']
  end

  if attributes.key?(:'metadata_items')
    self. = attributes[:'metadata_items']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'per_volume_gigabytes')
    self.per_volume_gigabytes = attributes[:'per_volume_gigabytes']
  end

  if attributes.key?(:'ram')
    self.ram = attributes[:'ram']
  end

  if attributes.key?(:'security_groups')
    self.security_groups = attributes[:'security_groups']
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  end
end

Instance Attribute Details

#coresObject

The number of instance cores that are allowed per project. doc-todo: what is a CORE?



20
21
22
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 20

def cores
  @cores
end

#descriptionObject

Project description.



23
24
25
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 23

def description
  @description
end

#fixed_ipsObject

The number of fixed IP addresses that are allowed per project. This number must be equal to or greater than the number of allowed instances.



26
27
28
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 26

def fixed_ips
  @fixed_ips
end

#floating_ipsObject

The number of floating IP addresses that are allowed per project.



29
30
31
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 29

def floating_ips
  @floating_ips
end

#groupsObject

The maximum number of groups.



32
33
34
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 32

def groups
  @groups
end

#injected_file_content_bytesObject

The number of bytes of content that are allowed for each injected file.



35
36
37
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 35

def injected_file_content_bytes
  @injected_file_content_bytes
end

#injected_file_path_bytesObject

The number of bytes that are allowed for each injected file path.



38
39
40
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 38

def injected_file_path_bytes
  @injected_file_path_bytes
end

#instancesObject

The number of instances that are allowed per project. doc-todo: what is an instance? does it mean how many projects can exist at once?



41
42
43
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 41

def instances
  @instances
end

#key_pairsObject

The number of key pairs that are allowed per user. doc-todo: what is a key pair?



44
45
46
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 44

def key_pairs
  @key_pairs
end

#max_total_backup_gigabytesObject

Maximum capacity (GB) allocated to backups.



47
48
49
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 47

def max_total_backup_gigabytes
  @max_total_backup_gigabytes
end

#max_total_backupsObject

Maximum number of backups. A backup is a full copy of a volume stored in an external service. The service can be configured. The only supported service is Object Storage. doc-todo:WHAT IS OBJECT STORAGE? A backup can subsequently be restored from the external service to either the same volume that the backup was originally taken from or to a new volume. Backup and restore operations can only be carried out on volumes that are in an unattached and available state.



50
51
52
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 50

def max_total_backups
  @max_total_backups
end

#max_total_snapshotsObject

Maximum number of snapshots allowed per project.



53
54
55
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 53

def max_total_snapshots
  @max_total_snapshots
end

#max_total_volume_gigabytesObject

Maximum number of gigabytes allocated to volumes per project.



56
57
58
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 56

def max_total_volume_gigabytes
  @max_total_volume_gigabytes
end

#max_total_volumesObject

Maximum number of provisioned volumes in the project.



59
60
61
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 59

def max_total_volumes
  @max_total_volumes
end

#metadata_itemsObject

The number of metadata items that are allowed for each instance.



62
63
64
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 62

def 
  @metadata_items
end

#nameObject

Project name.



65
66
67
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 65

def name
  @name
end

#per_volume_gigabytesObject

The size (GB) of volumes in request that are allowed per volume.



68
69
70
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 68

def per_volume_gigabytes
  @per_volume_gigabytes
end

#ramObject

The amount of instance RAM (MB) that are allowed per project. doc-todo: RAM per project, per specific project.…?



71
72
73
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 71

def ram
  @ram
end

#security_groupsObject

The number of security groups that are allowed per project.



74
75
76
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 74

def security_groups
  @security_groups
end

#uuidObject

UUID



77
78
79
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 77

def uuid
  @uuid
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 80

def self.attribute_map
  {
    :'cores' => :'cores',
    :'description' => :'description',
    :'fixed_ips' => :'fixed_ips',
    :'floating_ips' => :'floating_ips',
    :'groups' => :'groups',
    :'injected_file_content_bytes' => :'injected_file_content_bytes',
    :'injected_file_path_bytes' => :'injected_file_path_bytes',
    :'instances' => :'instances',
    :'key_pairs' => :'key_pairs',
    :'max_total_backup_gigabytes' => :'max_total_backup_gigabytes',
    :'max_total_backups' => :'max_total_backups',
    :'max_total_snapshots' => :'max_total_snapshots',
    :'max_total_volume_gigabytes' => :'max_total_volume_gigabytes',
    :'max_total_volumes' => :'max_total_volumes',
    :'metadata_items' => :'metadata_items',
    :'name' => :'name',
    :'per_volume_gigabytes' => :'per_volume_gigabytes',
    :'ram' => :'ram',
    :'security_groups' => :'security_groups',
    :'uuid' => :'uuid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 288

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 106

def self.openapi_types
  {
    :'cores' => :'Integer',
    :'description' => :'String',
    :'fixed_ips' => :'Integer',
    :'floating_ips' => :'Integer',
    :'groups' => :'Integer',
    :'injected_file_content_bytes' => :'Float',
    :'injected_file_path_bytes' => :'Integer',
    :'instances' => :'Integer',
    :'key_pairs' => :'Integer',
    :'max_total_backup_gigabytes' => :'Float',
    :'max_total_backups' => :'Integer',
    :'max_total_snapshots' => :'Integer',
    :'max_total_volume_gigabytes' => :'Float',
    :'max_total_volumes' => :'Integer',
    :'metadata_items' => :'Integer',
    :'name' => :'String',
    :'per_volume_gigabytes' => :'Float',
    :'ram' => :'Float',
    :'security_groups' => :'Integer',
    :'uuid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 248

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cores == o.cores &&
      description == o.description &&
      fixed_ips == o.fixed_ips &&
      floating_ips == o.floating_ips &&
      groups == o.groups &&
      injected_file_content_bytes == o.injected_file_content_bytes &&
      injected_file_path_bytes == o.injected_file_path_bytes &&
      instances == o.instances &&
      key_pairs == o.key_pairs &&
      max_total_backup_gigabytes == o.max_total_backup_gigabytes &&
      max_total_backups == o.max_total_backups &&
      max_total_snapshots == o.max_total_snapshots &&
      max_total_volume_gigabytes == o.max_total_volume_gigabytes &&
      max_total_volumes == o.max_total_volumes &&
       == o. &&
      name == o.name &&
      per_volume_gigabytes == o.per_volume_gigabytes &&
      ram == o.ram &&
      security_groups == o.security_groups &&
      uuid == o.uuid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 318

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OpenapiClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 387

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 295

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 281

def hash
  [cores, description, fixed_ips, floating_ips, groups, injected_file_content_bytes, injected_file_path_bytes, instances, key_pairs, max_total_backup_gigabytes, max_total_backups, max_total_snapshots, max_total_volume_gigabytes, max_total_volumes, , name, per_volume_gigabytes, ram, security_groups, uuid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



235
236
237
238
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 235

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 363

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 369

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



357
358
359
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 357

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



242
243
244
# File 'lib/autosde_openapi_client/models/auto_sde_project.rb', line 242

def valid?
  true
end