Class: OpenapiClient::CapabilityTranslationCreate
- Inherits:
-
Object
- Object
- OpenapiClient::CapabilityTranslationCreate
- Defined in:
- lib/autosde_openapi_client/models/capability_translation_create.rb
Overview
TODO add description
Instance Attribute Summary collapse
-
#abstract_capability_name ⇒ Object
abstract_capability_name.
-
#default_value ⇒ Object
default_value.
-
#native_capability_name ⇒ Object
native_capability_name.
-
#published ⇒ Object
published.
-
#system_type_id ⇒ Object
system_type_id.
-
#to_abstract_value_mapper ⇒ Object
Maximum value length is 32 characters.
-
#to_native_value_mapper ⇒ Object
Maximum value length is 32 characters.
-
#uuid ⇒ Object
uuid.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CapabilityTranslationCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CapabilityTranslationCreate
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::CapabilityTranslationCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::CapabilityTranslationCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'abstract_capability_name') self.abstract_capability_name = attributes[:'abstract_capability_name'] end if attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] else self.default_value = ' ' end if attributes.key?(:'native_capability_name') self.native_capability_name = attributes[:'native_capability_name'] end if attributes.key?(:'published') self.published = attributes[:'published'] end if attributes.key?(:'system_type_id') self.system_type_id = attributes[:'system_type_id'] end if attributes.key?(:'to_abstract_value_mapper') self.to_abstract_value_mapper = attributes[:'to_abstract_value_mapper'] end if attributes.key?(:'to_native_value_mapper') self.to_native_value_mapper = attributes[:'to_native_value_mapper'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end end |
Instance Attribute Details
#abstract_capability_name ⇒ Object
abstract_capability_name
20 21 22 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 20 def abstract_capability_name @abstract_capability_name end |
#default_value ⇒ Object
default_value
23 24 25 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 23 def default_value @default_value end |
#native_capability_name ⇒ Object
native_capability_name
26 27 28 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 26 def native_capability_name @native_capability_name end |
#published ⇒ Object
published
29 30 31 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 29 def published @published end |
#system_type_id ⇒ Object
system_type_id
32 33 34 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 32 def system_type_id @system_type_id end |
#to_abstract_value_mapper ⇒ Object
Maximum value length is 32 characters.
35 36 37 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 35 def to_abstract_value_mapper @to_abstract_value_mapper end |
#to_native_value_mapper ⇒ Object
Maximum value length is 32 characters.
38 39 40 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 38 def to_native_value_mapper @to_native_value_mapper end |
#uuid ⇒ Object
uuid
41 42 43 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 41 def uuid @uuid end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 44 def self.attribute_map { :'abstract_capability_name' => :'abstract_capability_name', :'default_value' => :'default_value', :'native_capability_name' => :'native_capability_name', :'published' => :'published', :'system_type_id' => :'system_type_id', :'to_abstract_value_mapper' => :'to_abstract_value_mapper', :'to_native_value_mapper' => :'to_native_value_mapper', :'uuid' => :'uuid' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 200 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 58 def self.openapi_types { :'abstract_capability_name' => :'String', :'default_value' => :'String', :'native_capability_name' => :'String', :'published' => :'Boolean', :'system_type_id' => :'String', :'to_abstract_value_mapper' => :'String', :'to_native_value_mapper' => :'String', :'uuid' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 172 def ==(o) return true if self.equal?(o) self.class == o.class && abstract_capability_name == o.abstract_capability_name && default_value == o.default_value && native_capability_name == o.native_capability_name && published == o.published && system_type_id == o.system_type_id && to_abstract_value_mapper == o.to_abstract_value_mapper && to_native_value_mapper == o.to_native_value_mapper && uuid == o.uuid end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 230 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OpenapiClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 299 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 193 def hash [abstract_capability_name, default_value, native_capability_name, published, system_type_id, to_abstract_value_mapper, to_native_value_mapper, uuid].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 129 def list_invalid_properties invalid_properties = Array.new if !@to_abstract_value_mapper.nil? && @to_abstract_value_mapper.to_s.length > 32 invalid_properties.push('invalid value for "to_abstract_value_mapper", the character length must be smaller than or equal to 32.') end if !@to_native_value_mapper.nil? && @to_native_value_mapper.to_s.length > 32 invalid_properties.push('invalid value for "to_native_value_mapper", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
275 276 277 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 275 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
269 270 271 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 269 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 |
# File 'lib/autosde_openapi_client/models/capability_translation_create.rb', line 144 def valid? return false if !@to_abstract_value_mapper.nil? && @to_abstract_value_mapper.to_s.length > 32 return false if !@to_native_value_mapper.nil? && @to_native_value_mapper.to_s.length > 32 true end |