Class: OpenapiClient::Service
- Inherits:
-
Object
- Object
- OpenapiClient::Service
- Defined in:
- lib/autosde_openapi_client/models/service.rb
Overview
Service
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capability_values ⇒ Object
Returns the value of attribute capability_values.
-
#component_state ⇒ Object
component_state.
-
#description ⇒ Object
description.
-
#name ⇒ Object
name.
-
#profile ⇒ Object
Returns the value of attribute profile.
-
#project ⇒ Object
Returns the value of attribute project.
-
#provisioning_strategy ⇒ Object
Returns the value of attribute provisioning_strategy.
-
#resource_service ⇒ Object
resource_service.
-
#uuid ⇒ Object
uuid.
-
#version ⇒ Object
The version of the service.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Service
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Service
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/autosde_openapi_client/models/service.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::Service` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::Service`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'capability_values') self.capability_values = attributes[:'capability_values'] end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = '' end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'profile') self.profile = attributes[:'profile'] end if attributes.key?(:'project') self.project = attributes[:'project'] end if attributes.key?(:'provisioning_strategy') self.provisioning_strategy = attributes[:'provisioning_strategy'] end if attributes.key?(:'resource_service') self.resource_service = attributes[:'resource_service'] else self.resource_service = false end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = 1 end end |
Instance Attribute Details
#capability_values ⇒ Object
Returns the value of attribute capability_values.
19 20 21 |
# File 'lib/autosde_openapi_client/models/service.rb', line 19 def capability_values @capability_values end |
#component_state ⇒ Object
component_state
22 23 24 |
# File 'lib/autosde_openapi_client/models/service.rb', line 22 def component_state @component_state end |
#description ⇒ Object
description
25 26 27 |
# File 'lib/autosde_openapi_client/models/service.rb', line 25 def description @description end |
#name ⇒ Object
name
28 29 30 |
# File 'lib/autosde_openapi_client/models/service.rb', line 28 def name @name end |
#profile ⇒ Object
Returns the value of attribute profile.
30 31 32 |
# File 'lib/autosde_openapi_client/models/service.rb', line 30 def profile @profile end |
#project ⇒ Object
Returns the value of attribute project.
32 33 34 |
# File 'lib/autosde_openapi_client/models/service.rb', line 32 def project @project end |
#provisioning_strategy ⇒ Object
Returns the value of attribute provisioning_strategy.
34 35 36 |
# File 'lib/autosde_openapi_client/models/service.rb', line 34 def provisioning_strategy @provisioning_strategy end |
#resource_service ⇒ Object
resource_service
37 38 39 |
# File 'lib/autosde_openapi_client/models/service.rb', line 37 def resource_service @resource_service end |
#uuid ⇒ Object
uuid
40 41 42 |
# File 'lib/autosde_openapi_client/models/service.rb', line 40 def uuid @uuid end |
#version ⇒ Object
The version of the service
43 44 45 |
# File 'lib/autosde_openapi_client/models/service.rb', line 43 def version @version end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/autosde_openapi_client/models/service.rb', line 68 def self.attribute_map { :'capability_values' => :'capability_values', :'component_state' => :'component_state', :'description' => :'description', :'name' => :'name', :'profile' => :'profile', :'project' => :'project', :'provisioning_strategy' => :'provisioning_strategy', :'resource_service' => :'resource_service', :'uuid' => :'uuid', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 |
# File 'lib/autosde_openapi_client/models/service.rb', line 229 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/autosde_openapi_client/models/service.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/autosde_openapi_client/models/service.rb', line 84 def self.openapi_types { :'capability_values' => :'ServiceAbstractCapabilityValue', :'component_state' => :'String', :'description' => :'String', :'name' => :'String', :'profile' => :'Profile', :'project' => :'AutoSDEProject', :'provisioning_strategy' => :'ProvisioningStrategy', :'resource_service' => :'Boolean', :'uuid' => :'String', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/autosde_openapi_client/models/service.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && capability_values == o.capability_values && component_state == o.component_state && description == o.description && name == o.name && profile == o.profile && project == o.project && provisioning_strategy == o.provisioning_strategy && resource_service == o.resource_service && uuid == o.uuid && version == o.version end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/autosde_openapi_client/models/service.rb', line 259 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OpenapiClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/autosde_openapi_client/models/service.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/autosde_openapi_client/models/service.rb', line 236 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/autosde_openapi_client/models/service.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/autosde_openapi_client/models/service.rb', line 222 def hash [capability_values, component_state, description, name, profile, project, provisioning_strategy, resource_service, uuid, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 |
# File 'lib/autosde_openapi_client/models/service.rb', line 169 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
304 305 306 |
# File 'lib/autosde_openapi_client/models/service.rb', line 304 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/autosde_openapi_client/models/service.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/autosde_openapi_client/models/service.rb', line 298 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 |
# File 'lib/autosde_openapi_client/models/service.rb', line 180 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 true end |