Class: OpenapiClient::StorageHostCreate
- Inherits:
-
Object
- Object
- OpenapiClient::StorageHostCreate
- Defined in:
- lib/autosde_openapi_client/models/storage_host_create.rb
Overview
TODO add description
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#chap_name ⇒ Object
chap_name.
-
#chap_secret ⇒ Object
chap_secret.
-
#component_state ⇒ Object
component_state.
-
#description ⇒ Object
description.
-
#io_groups ⇒ Object
io_groups.
-
#iqn ⇒ Object
Returns the value of attribute iqn.
-
#name ⇒ Object
The Storage Host Name.
-
#port_type ⇒ Object
port_type.
-
#storage_system ⇒ Object
Returns the value of attribute storage_system.
-
#volumes ⇒ Object
Returns the value of attribute volumes.
-
#wwpn ⇒ Object
wwpn.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StorageHostCreate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StorageHostCreate
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::StorageHostCreate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::StorageHostCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'chap_name') self.chap_name = attributes[:'chap_name'] end if attributes.key?(:'chap_secret') self.chap_secret = attributes[:'chap_secret'] end if attributes.key?(:'component_state') self.component_state = attributes[:'component_state'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'io_groups') self.io_groups = attributes[:'io_groups'] end if attributes.key?(:'iqn') self.iqn = attributes[:'iqn'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'port_type') self.port_type = attributes[:'port_type'] end if attributes.key?(:'storage_system') self.storage_system = attributes[:'storage_system'] end if attributes.key?(:'volumes') self.volumes = attributes[:'volumes'] end if attributes.key?(:'wwpn') self.wwpn = attributes[:'wwpn'] end end |
Instance Attribute Details
#chap_name ⇒ Object
chap_name
20 21 22 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 20 def chap_name @chap_name end |
#chap_secret ⇒ Object
chap_secret
23 24 25 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 23 def chap_secret @chap_secret end |
#component_state ⇒ Object
component_state
26 27 28 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 26 def component_state @component_state end |
#description ⇒ Object
description
29 30 31 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 29 def description @description end |
#io_groups ⇒ Object
io_groups
32 33 34 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 32 def io_groups @io_groups end |
#iqn ⇒ Object
Returns the value of attribute iqn.
34 35 36 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 34 def iqn @iqn end |
#name ⇒ Object
The Storage Host Name
37 38 39 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 37 def name @name end |
#port_type ⇒ Object
port_type
40 41 42 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 40 def port_type @port_type end |
#storage_system ⇒ Object
Returns the value of attribute storage_system.
42 43 44 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 42 def storage_system @storage_system end |
#volumes ⇒ Object
Returns the value of attribute volumes.
44 45 46 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 44 def volumes @volumes end |
#wwpn ⇒ Object
wwpn
47 48 49 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 47 def wwpn @wwpn end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 72 def self.attribute_map { :'chap_name' => :'chap_name', :'chap_secret' => :'chap_secret', :'component_state' => :'component_state', :'description' => :'description', :'io_groups' => :'io_groups', :'iqn' => :'iqn', :'name' => :'name', :'port_type' => :'port_type', :'storage_system' => :'storage_system', :'volumes' => :'volumes', :'wwpn' => :'wwpn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 246 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 89 def self.openapi_types { :'chap_name' => :'String', :'chap_secret' => :'String', :'component_state' => :'String', :'description' => :'String', :'io_groups' => :'String', :'iqn' => :'String', :'name' => :'String', :'port_type' => :'String', :'storage_system' => :'StorageSystem', :'volumes' => :'Volume', :'wwpn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && chap_name == o.chap_name && chap_secret == o.chap_secret && component_state == o.component_state && description == o.description && io_groups == o.io_groups && iqn == o.iqn && name == o.name && port_type == o.port_type && storage_system == o.storage_system && volumes == o.volumes && wwpn == o.wwpn end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 276 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model OpenapiClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 345 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 253 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 239 def hash [chap_name, chap_secret, component_state, description, io_groups, iqn, name, port_type, storage_system, volumes, wwpn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 173 def list_invalid_properties invalid_properties = Array.new if !@component_state.nil? && @component_state.to_s.length > 32 invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
321 322 323 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 321 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 327 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
315 316 317 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 315 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 188 189 190 191 |
# File 'lib/autosde_openapi_client/models/storage_host_create.rb', line 184 def valid? component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"]) return false unless component_state_validator.valid?(@component_state) return false if !@component_state.nil? && @component_state.to_s.length > 32 port_type_validator = EnumAttributeValidator.new('String', ["ISCSI", "FC", "NVMeFC"]) return false unless port_type_validator.valid?(@port_type) true end |