Class: OpenapiClient::StorageResourceCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/autosde_openapi_client/models/storage_resource_create.rb

Overview

TODO add description

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageResourceCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::StorageResourceCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::StorageResourceCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'advanced_attributes_map')
    self.advanced_attributes_map = attributes[:'advanced_attributes_map']
  end

  if attributes.key?(:'component_state')
    self.component_state = attributes[:'component_state']
  end

  if attributes.key?(:'logical_free')
    self.logical_free = attributes[:'logical_free']
  else
    self.logical_free = 0
  end

  if attributes.key?(:'logical_total')
    self.logical_total = attributes[:'logical_total']
  else
    self.logical_total = 0
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'pool_name')
    self.pool_name = attributes[:'pool_name']
  end

  if attributes.key?(:'protocol')
    self.protocol = attributes[:'protocol']
  end

  if attributes.key?(:'storage_system')
    self.storage_system = attributes[:'storage_system']
  end
end

Instance Attribute Details

#advanced_attributes_mapObject

advanced_attributes_map



20
21
22
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 20

def advanced_attributes_map
  @advanced_attributes_map
end

#component_stateObject

component_state



23
24
25
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 23

def component_state
  @component_state
end

#logical_freeObject

logical_free



26
27
28
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 26

def logical_free
  @logical_free
end

#logical_totalObject

The Total logical capacity of this resource (gb)



29
30
31
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 29

def logical_total
  @logical_total
end

#nameObject

name



32
33
34
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 32

def name
  @name
end

#pool_nameObject

Pool (or slice) name



35
36
37
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 35

def pool_name
  @pool_name
end

#protocolObject

protocol



38
39
40
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 38

def protocol
  @protocol
end

#storage_systemObject

!!uuid of storage_system



41
42
43
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 41

def storage_system
  @storage_system
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 66

def self.attribute_map
  {
    :'advanced_attributes_map' => :'advanced_attributes_map',
    :'component_state' => :'component_state',
    :'logical_free' => :'logical_free',
    :'logical_total' => :'logical_total',
    :'name' => :'name',
    :'pool_name' => :'pool_name',
    :'protocol' => :'protocol',
    :'storage_system' => :'storage_system'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 223

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 80

def self.openapi_types
  {
    :'advanced_attributes_map' => :'String',
    :'component_state' => :'String',
    :'logical_free' => :'Integer',
    :'logical_total' => :'Integer',
    :'name' => :'String',
    :'pool_name' => :'String',
    :'protocol' => :'String',
    :'storage_system' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      advanced_attributes_map == o.advanced_attributes_map &&
      component_state == o.component_state &&
      logical_free == o.logical_free &&
      logical_total == o.logical_total &&
      name == o.name &&
      pool_name == o.pool_name &&
      protocol == o.protocol &&
      storage_system == o.storage_system
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 253

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    OpenapiClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 322

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 230

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 216

def hash
  [advanced_attributes_map, component_state, logical_free, logical_total, name, pool_name, protocol, storage_system].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 153

def list_invalid_properties
  invalid_properties = Array.new
  if !@component_state.nil? && @component_state.to_s.length > 32
    invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 298

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



292
293
294
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 292

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
168
169
170
171
# File 'lib/autosde_openapi_client/models/storage_resource_create.rb', line 164

def valid?
  component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"])
  return false unless component_state_validator.valid?(@component_state)
  return false if !@component_state.nil? && @component_state.to_s.length > 32
  protocol_validator = EnumAttributeValidator.new('String', ["fc", "iscsi"])
  return false unless protocol_validator.valid?(@protocol)
  true
end