Method: OpenapiClient::VolumeSafeDelete#initialize
- Defined in:
- lib/autosde_openapi_client/models/volume_safe_delete.rb
#initialize(attributes = {}) ⇒ VolumeSafeDelete
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/autosde_openapi_client/models/volume_safe_delete.rb', line 53 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `OpenapiClient::VolumeSafeDelete` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `OpenapiClient::VolumeSafeDelete`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'task_id') self.task_id = attributes[:'task_id'] end if attributes.key?(:'uuid') self.uuid = attributes[:'uuid'] end if attributes.key?(:'volume') self.volume = attributes[:'volume'] end end |