Class: AutosdeOpenapiClient::StorageSystemCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/autosde_openapi_client/models/storage_system_create.rb

Overview

TODO add description

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StorageSystemCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AutosdeOpenapiClient::StorageSystemCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AutosdeOpenapiClient::StorageSystemCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_add_pools')
    self.auto_add_pools = attributes[:'auto_add_pools']
  else
    self.auto_add_pools = false
  end

  if attributes.key?(:'auto_setup')
    self.auto_setup = attributes[:'auto_setup']
  else
    self.auto_setup = false
  end

  if attributes.key?(:'chap_name')
    self.chap_name = attributes[:'chap_name']
  end

  if attributes.key?(:'chap_secret')
    self.chap_secret = attributes[:'chap_secret']
  end

  if attributes.key?(:'component_state')
    self.component_state = attributes[:'component_state']
  end

  if attributes.key?(:'iqn')
    self.iqn = attributes[:'iqn']
  end

  if attributes.key?(:'management_ip')
    self.management_ip = attributes[:'management_ip']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'port_type')
    self.port_type = attributes[:'port_type']
  end

  if attributes.key?(:'secondary_ip')
    self.secondary_ip = attributes[:'secondary_ip']
  end

  if attributes.key?(:'storage_array')
    self.storage_array = attributes[:'storage_array']
  end

  if attributes.key?(:'storage_driver')
    self.storage_driver = attributes[:'storage_driver']
  end

  if attributes.key?(:'storage_family')
    self.storage_family = attributes[:'storage_family']
  end

  if attributes.key?(:'system_type')
    self.system_type = attributes[:'system_type']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'wwpn')
    self.wwpn = attributes[:'wwpn']
  end
end

Instance Attribute Details

#auto_add_poolsObject

auto_add_pools



20
21
22
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 20

def auto_add_pools
  @auto_add_pools
end

#auto_setupObject

auto_setup



23
24
25
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 23

def auto_setup
  @auto_setup
end

#chap_nameObject

chap_name



26
27
28
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 26

def chap_name
  @chap_name
end

#chap_secretObject

chap_secret



29
30
31
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 29

def chap_secret
  @chap_secret
end

#component_stateObject

component_state



32
33
34
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 32

def component_state
  @component_state
end

#iqnObject

Returns the value of attribute iqn.



34
35
36
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 34

def iqn
  @iqn
end

#management_ipObject

management_ip



37
38
39
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 37

def management_ip
  @management_ip
end

#nameObject

name



40
41
42
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 40

def name
  @name
end

#passwordObject

password



43
44
45
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 43

def password
  @password
end

#port_typeObject

port_type



46
47
48
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 46

def port_type
  @port_type
end

#secondary_ipObject

secondary_ip



49
50
51
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 49

def secondary_ip
  @secondary_ip
end

#storage_arrayObject

storage_array



52
53
54
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 52

def storage_array
  @storage_array
end

#storage_driverObject

storage_driver



55
56
57
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 55

def storage_driver
  @storage_driver
end

#storage_familyObject

storage_family



58
59
60
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 58

def storage_family
  @storage_family
end

#system_typeObject

Returns the value of attribute system_type.



60
61
62
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 60

def system_type
  @system_type
end

#userObject

user



63
64
65
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 63

def user
  @user
end

#wwpnObject

wwpn



66
67
68
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 66

def wwpn
  @wwpn
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 91

def self.attribute_map
  {
    :'auto_add_pools' => :'auto_add_pools',
    :'auto_setup' => :'auto_setup',
    :'chap_name' => :'chap_name',
    :'chap_secret' => :'chap_secret',
    :'component_state' => :'component_state',
    :'iqn' => :'iqn',
    :'management_ip' => :'management_ip',
    :'name' => :'name',
    :'password' => :'password',
    :'port_type' => :'port_type',
    :'secondary_ip' => :'secondary_ip',
    :'storage_array' => :'storage_array',
    :'storage_driver' => :'storage_driver',
    :'storage_family' => :'storage_family',
    :'system_type' => :'system_type',
    :'user' => :'user',
    :'wwpn' => :'wwpn'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 343

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 119

def self.openapi_types
  {
    :'auto_add_pools' => :'Boolean',
    :'auto_setup' => :'Boolean',
    :'chap_name' => :'String',
    :'chap_secret' => :'String',
    :'component_state' => :'String',
    :'iqn' => :'String',
    :'management_ip' => :'String',
    :'name' => :'String',
    :'password' => :'String',
    :'port_type' => :'String',
    :'secondary_ip' => :'String',
    :'storage_array' => :'String',
    :'storage_driver' => :'String',
    :'storage_family' => :'String',
    :'system_type' => :'SystemType',
    :'user' => :'String',
    :'wwpn' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 306

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_add_pools == o.auto_add_pools &&
      auto_setup == o.auto_setup &&
      chap_name == o.chap_name &&
      chap_secret == o.chap_secret &&
      component_state == o.component_state &&
      iqn == o.iqn &&
      management_ip == o.management_ip &&
      name == o.name &&
      password == o.password &&
      port_type == o.port_type &&
      secondary_ip == o.secondary_ip &&
      storage_array == o.storage_array &&
      storage_driver == o.storage_driver &&
      storage_family == o.storage_family &&
      system_type == o.system_type &&
      user == o.user &&
      wwpn == o.wwpn
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 373

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = AutosdeOpenapiClient.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 444

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 350

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


330
331
332
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 330

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



336
337
338
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 336

def hash
  [auto_add_pools, auto_setup, chap_name, chap_secret, component_state, iqn, management_ip, name, password, port_type, secondary_ip, storage_array, storage_driver, storage_family, system_type, user, wwpn].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 237

def list_invalid_properties
  invalid_properties = Array.new
  if !@component_state.nil? && @component_state.to_s.length > 32
    invalid_properties.push('invalid value for "component_state", the character length must be smaller than or equal to 32.')
  end

  if !@name.nil? && @name.to_s.length > 15
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 15.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 420

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 426

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



414
415
416
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 414

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
255
256
257
258
259
260
261
262
# File 'lib/autosde_openapi_client/models/storage_system_create.rb', line 252

def valid?
  component_state_validator = EnumAttributeValidator.new('String', ["PENDING_CREATION", "CREATED", "DELETED", "PENDING_DELETION", "MODIFICATION", "PENDING_MODIFICATION"])
  return false unless component_state_validator.valid?(@component_state)
  return false if !@component_state.nil? && @component_state.to_s.length > 32
  return false if !@name.nil? && @name.to_s.length > 15
  port_type_validator = EnumAttributeValidator.new('String', ["ISCSI", "FC", "NVMeFC"])
  return false unless port_type_validator.valid?(@port_type)
  storage_family_validator = EnumAttributeValidator.new('String', ["", "ontap_7mode", "ontap_cluster"])
  return false unless storage_family_validator.valid?(@storage_family)
  true
end